@@ -8,33 +8,34 @@ matlab <- function() {
   "The following functions are emulations of corresponding Matlab functions",
   "and bear the same signature as their Matlab cousins as far as possible:",
   "
-  accumarray, acot, acoth, acsc, acsch, and, angle, ans, asec, asech,
+  accumarray, acot, acoth, acsc, acsch, and, angle, ans, arrayfun, asec, asech,
   beep, blank, blkdiag, bsxfun,
   cart2pol, cart2sph, cd, ceil, circshift, clear, compan, cond, conv,
       cot, coth, cross, csc, csch,
-  deblank, deconv, deg2rad, detrend, deval, disp, dot,
+  dblquad, deblank, deconv, deg2rad, detrend, deval, disp, dot,
   eig, eigint, ellipj, ellipke, erf, erfc, erfcinv, erfcx, erfi, erfinv,
       errorbar, expint, expm, eye, ezcontour, ezmesh, ezplot, ezpolar,
-  fact, factors, fftshift, figure, findstr, flipdim, fliplr, flipud,
-      fminbnd, fminsearch, fplot, fsolve, fzero,
+  fact, factors, fftshift, figure, findpeaks, findstr, flipdim, fliplr,
+      flipud, fminbnd, fminsearch, fplot, fsolve, fzero,
   gammainc, gcd, geomean, gradient,
   hadamard, hankel, harmmean, hilb, histc, humps, hypot,
-  ifft, ifftshift, inpolygon, interp1, interp2, inv, isempty, isprime,
+  idivide, ifft, ifftshift, inpolygon, integral, integral2, integral3,
+      interp1, interp2, inv, isempty, isprime,
   kron,
-  linspace, loglog, logm, logseq, logspace, lsqcurvefit, lsqlin,
+  linprog, linspace, loglog, logm, logseq, logspace, lsqcurvefit, lsqlin,
       lsqnonlin, lsqnonneg, lu,
   magic, meshgrid, mkpp, mldivide, mod, mrdivide,
   nchoosek, ndims, nextpow2, nnz, normest, nthroot, null, num2str, numel,
   ode23, ones, or, orth,
   pascal, pchip, pdist, peaks, perms, piecewise, pinv, plotyy, pol2cart,
       polar, polyfit, polyint, polylog, polyval, pow2, ppval, primes, pwd,
-  quad, quad2d, quadgk, quadl, quadv, quiver,
+  quad, quad2d, quadgk, quadl, quadprog, quadv, quiver,
   rad2deg, randi, randn, randsample, rat, rats, regexp, regexpi, regexpreg,
       rem, repmat, roots, rosser, rot90, rref, runge,
   sec, sech, semilogx, semilogy, sinc, size, sortrows, sph2cart, sqrtm,
-      std, str2num, strcat, strcmp, strcmpi, strfind, strfindi, strjust,
-      strrep, subspace,
-  tic, toc, trapz, tril, trimmean, triu,
+      squareform, std, str2num, strcat, strcmp, strcmpi, strfind, strfindi,
+      strjust, strrep, subspace,
+  tic, toc, trapz, tril, trimmean, triplequad, triu,
   vander, vectorfield, ver,
   what, who, whos, wilkinson,
   zeros, zeta.",
