@@ -18,9 +18,9 @@ assign("elapsedTime", 0, envir = .pracmaEnv)
 
     environment(.pracmaEnv) <- asNamespace("pracma")
 
-    packageStartupMessage(
-        paste("pracma Package Version 1.3.3\n",
-              "Practical Numerical Math Functions\n",
-              "Copyright (c) 2011-2012 Hans W Borchers\n",
-        sep='', collapse=''))
+    # packageStartupMessage(
+    #     paste("pracma Package Version 1.4.0\n",
+    #           "Practical Numerical Math Functions\n",
+    #           "Copyright (c) 2011-2013 Hans W Borchers\n",
+    #     sep='', collapse=''))
 }
